@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
+/* -*- Mode: C++; c-basic-offset: 4 -*- */
 
 /*
  *  ORBit-C++: C++ bindings for ORBit.
@@ -42,23 +42,24 @@ using namespace _orbitcpp;
 
 CORBA::ORB::ORB(CORBA_ORB cobject)
 {
-  m_target = cobject;
+    m_target = cobject;
 }
 
-CORBA::ORB_ptr CORBA::ORB_init(int& argc, char** argv, const char* orb_identifier) {
-	CEnvironment ev;
-	CORBA_ORB o = CORBA_ORB_init(&argc, argv, const_cast<char*>(orb_identifier), ev._orbitcpp_cobj());
-	ev.propagate_sysex();
+CORBA::ORB_ptr CORBA::ORB_init (int &argc, char **argv, const char *orb_identifier) {
+    CEnvironment ev;
+    CORBA_ORB o = CORBA_ORB_init (&argc, argv, const_cast<char*> (orb_identifier),
+				  ev._orbitcpp_cobj ());
+    ev.propagate_sysex ();
 
-	return new ORB(o);
+    return new ORB (o);
 }
 
 
 
 
 void
-CORBA::release(ORB_ptr orb) {
-	delete orb;
+CORBA::release (ORB_ptr orb) {
+    delete orb;
 }
 
 
@@ -66,61 +67,64 @@ CORBA::release(ORB_ptr orb) {
 
 // ORB ------------------------------------------------------------------------
 CORBA::Object_ptr
-CORBA::ORB::string_to_object(const char* str)
+CORBA::ORB::string_to_object (const char* str)
 {
-	CEnvironment ev;
-	CORBA_Object o = CORBA_ORB_string_to_object(m_target, const_cast<char*>(str), ev._orbitcpp_cobj());
-	ev.propagate_sysex();
-
-	return new CORBA::Object(o);
+    CEnvironment ev;
+    CORBA_Object o = CORBA_ORB_string_to_object (m_target, const_cast<char*> (str),
+						 ev._orbitcpp_cobj ());
+    ev.propagate_sysex ();
+    
+    return new CORBA::Object (o);
 }
 
 CORBA::Object_ptr
-CORBA::ORB::string_to_object(const std::string &str)
+CORBA::ORB::string_to_object (const std::string &str)
 {
-	return string_to_object(str.c_str ());
+    return string_to_object (str.c_str ());
 }
 
 
 char *
-CORBA::ORB::object_to_string(Object_ptr obj) {
-	CEnvironment ev;
-	char *str = CORBA_ORB_object_to_string(m_target, obj->_orbitcpp_cobj(), ev._orbitcpp_cobj());
-	ev.propagate_sysex();
-	return str;
+CORBA::ORB::object_to_string (Object_ptr obj) {
+    CEnvironment ev;
+    char *str = CORBA_ORB_object_to_string (m_target, obj->_orbitcpp_cobj (),
+					    ev._orbitcpp_cobj ());
+    ev.propagate_sysex ();
+    return str;
 }
 
 
 
 
 CORBA::Object_ptr
-CORBA::ORB::resolve_initial_references(const char* str) {
-	CEnvironment ev;
-	CORBA_Object obj = CORBA_ORB_resolve_initial_references(m_target, const_cast<char*>(str), ev._orbitcpp_cobj());
-	ev.propagate_sysex();
-
-	return new CORBA::Object(obj);
+CORBA::ORB::resolve_initial_references (const char* str) {
+    CEnvironment ev;
+    CORBA_Object obj = CORBA_ORB_resolve_initial_references (m_target, const_cast<char*> (str),
+							     ev._orbitcpp_cobj ());
+    ev.propagate_sysex ();
+	
+    return new CORBA::Object (obj);
 }
 
 
 
 
 CORBA::Boolean 
-CORBA::ORB::work_pending() {
-	CEnvironment ev;
-	Boolean result = CORBA_ORB_work_pending(m_target, ev._orbitcpp_cobj());
-	ev.propagate_sysex();
-	return result;
+CORBA::ORB::work_pending () {
+    CEnvironment ev;
+    Boolean result = CORBA_ORB_work_pending (m_target, ev._orbitcpp_cobj ());
+    ev.propagate_sysex ();
+    return result;
 }
   
   
   
   
 void 
-CORBA::ORB::perform_work() {
-	CEnvironment ev;
-	CORBA_ORB_perform_work(m_target, ev._orbitcpp_cobj());
-	ev.propagate_sysex();
+CORBA::ORB::perform_work () {
+    CEnvironment ev;
+    CORBA_ORB_perform_work (m_target, ev._orbitcpp_cobj ());
+    ev.propagate_sysex ();
 }
 
 
